@@ -3,8 +3,7 @@ package shim
 import (
 	"errors"
 	"fmt"
-	"io/ioutil"
-	"log"
+	"log" //nolint:revive // Allow exceptional but valid use of log here.
 	"os"
 
 	"github.com/BurntSushi/toml"
@@ -53,7 +52,7 @@ func LoadConfig(filePath *string) (loaded loadedConfig, err error) {
 	var data string
 	conf := config{}
 	if filePath != nil && *filePath != "" {
-		b, err := ioutil.ReadFile(*filePath)
+		b, err := os.ReadFile(*filePath)
 		if err != nil {
 			return loadedConfig{}, err
 		}
