@@ -4,17 +4,16 @@ import (
 	"crypto/tls"
 	"fmt"
 	"math"
-	"net"
 	"strconv"
 	"strings"
 	"sync"
 	"time"
 
+	as "github.com/aerospike/aerospike-client-go/v5"
+
 	"github.com/influxdata/telegraf"
 	tlsint "github.com/influxdata/telegraf/plugins/common/tls"
 	"github.com/influxdata/telegraf/plugins/inputs"
-
-	as "github.com/aerospike/aerospike-client-go"
 )
 
 type Aerospike struct {
@@ -23,8 +22,9 @@ type Aerospike struct {
 	Username string `toml:"username"`
 	Password string `toml:"password"`
 
-	EnableTLS bool `toml:"enable_tls"`
-	EnableSSL bool `toml:"enable_ssl"` // deprecated in 1.7; use enable_tls
+	EnableTLS bool   `toml:"enable_tls"`
+	EnableSSL bool   `toml:"enable_ssl" deprecated:"1.7.0;use 'enable_tls' instead"`
+	TLSName   string `toml:"tls_name"`
 	tlsint.ClientConfig
 
 	initialized bool
@@ -56,6 +56,7 @@ var sampleConfig = `
   # tls_ca = "/etc/telegraf/ca.pem"
   # tls_cert = "/etc/telegraf/cert.pem"
   # tls_key = "/etc/telegraf/key.pem"
+  # tls_name = "tlsname"
   ## If false, skip chain & host verification
   # insecure_skip_verify = true
 
@@ -65,7 +66,7 @@ var sampleConfig = `
   # disable_query_namespaces = true # default false
   # namespaces = ["namespace1", "namespace2"]
 
-  # Enable set level telmetry
+  # Enable set level telemetry
   # query_sets = true # default: false
   # Add namespace set combinations to limit sets executed on
   # Leave blank to do all sets
@@ -77,7 +78,9 @@ var sampleConfig = `
 
   # by default, aerospike produces a 100 bucket histogram
   # this is not great for most graphing tools, this will allow
-  # the ability to squash this to a smaller number of buckets 
+  # the ability to squash this to a smaller number of buckets
+  # To have a balanced histogram, the number of buckets chosen
+  # should divide evenly into 100.
   # num_histogram_buckets = 100 # default: 10
 `
 
@@ -119,7 +122,7 @@ func (a *Aerospike) Gather(acc telegraf.Accumulator) error {
 	}
 
 	if len(a.Servers) == 0 {
-		return a.gatherServer("127.0.0.1:3000", acc)
+		return a.gatherServer(acc, "127.0.0.1:3000")
 	}
 
 	var wg sync.WaitGroup
@@ -127,7 +130,7 @@ func (a *Aerospike) Gather(acc telegraf.Accumulator) error {
 	for _, server := range a.Servers {
 		go func(serv string) {
 			defer wg.Done()
-			acc.AddError(a.gatherServer(serv, acc))
+			acc.AddError(a.gatherServer(acc, serv))
 		}(server)
 	}
 
@@ -135,36 +138,37 @@ func (a *Aerospike) Gather(acc telegraf.Accumulator) error {
 	return nil
 }
 
-func (a *Aerospike) gatherServer(hostPort string, acc telegraf.Accumulator) error {
-	host, port, err := net.SplitHostPort(hostPort)
-	if err != nil {
-		return err
-	}
-
-	iport, err := strconv.Atoi(port)
-	if err != nil {
-		iport = 3000
-	}
-
+func (a *Aerospike) gatherServer(acc telegraf.Accumulator, hostPort string) error {
 	policy := as.NewClientPolicy()
 	policy.User = a.Username
 	policy.Password = a.Password
 	policy.TlsConfig = a.tlsConfig
-	c, err := as.NewClientWithPolicy(policy, host, iport)
+	asHosts, err := as.NewHosts(hostPort)
 	if err != nil {
 		return err
 	}
+	if a.TLSName != "" && (a.EnableTLS || a.EnableSSL) {
+		for _, asHost := range asHosts {
+			asHost.TLSName = a.TLSName
+		}
+	}
+	c, err := as.NewClientWithPolicyAndHost(policy, asHosts...)
+	if err != nil {
+		return err
+	}
+	asInfoPolicy := as.NewInfoPolicy()
 	defer c.Close()
 
 	nodes := c.GetNodes()
 	for _, n := range nodes {
-		stats, err := a.getNodeInfo(n)
+		nodeHost := n.GetHost().String()
+		stats, err := a.getNodeInfo(n, asInfoPolicy)
 		if err != nil {
 			return err
 		}
-		a.parseNodeInfo(stats, hostPort, n.GetName(), acc)
+		a.parseNodeInfo(acc, stats, nodeHost, n.GetName())
 
-		namespaces, err := a.getNamespaces(n)
+		namespaces, err := a.getNamespaces(n, asInfoPolicy)
 		if err != nil {
 			return err
 		}
@@ -172,22 +176,21 @@ func (a *Aerospike) gatherServer(hostPort string, acc telegraf.Accumulator) erro
 		if !a.DisableQueryNamespaces {
 			// Query Namespaces
 			for _, namespace := range namespaces {
-				stats, err = a.getNamespaceInfo(namespace, n)
+				stats, err = a.getNamespaceInfo(namespace, n, asInfoPolicy)
 
 				if err != nil {
 					continue
-				} else {
-					a.parseNamespaceInfo(stats, hostPort, namespace, n.GetName(), acc)
 				}
+				a.parseNamespaceInfo(acc, stats, nodeHost, namespace, n.GetName())
 
 				if a.EnableTTLHistogram {
-					err = a.getTTLHistogram(hostPort, namespace, "", n, acc)
+					err = a.getTTLHistogram(acc, nodeHost, namespace, "", n, asInfoPolicy)
 					if err != nil {
 						continue
 					}
 				}
 				if a.EnableObjectSizeLinearHistogram {
-					err = a.getObjectSizeLinearHistogram(hostPort, namespace, "", n, acc)
+					err = a.getObjectSizeLinearHistogram(acc, nodeHost, namespace, "", n, asInfoPolicy)
 					if err != nil {
 						continue
 					}
@@ -196,28 +199,26 @@ func (a *Aerospike) gatherServer(hostPort string, acc telegraf.Accumulator) erro
 		}
 
 		if a.QuerySets {
-			namespaceSets, err := a.getSets(n)
+			namespaceSets, err := a.getSets(n, asInfoPolicy)
 			if err == nil {
 				for _, namespaceSet := range namespaceSets {
 					namespace, set := splitNamespaceSet(namespaceSet)
-
-					stats, err := a.getSetInfo(namespaceSet, n)
+					stats, err := a.getSetInfo(namespaceSet, n, asInfoPolicy)
 
 					if err != nil {
 						continue
-					} else {
-						a.parseSetInfo(stats, hostPort, namespaceSet, n.GetName(), acc)
 					}
+					a.parseSetInfo(acc, stats, nodeHost, namespaceSet, n.GetName())
 
 					if a.EnableTTLHistogram {
-						err = a.getTTLHistogram(hostPort, namespace, set, n, acc)
+						err = a.getTTLHistogram(acc, nodeHost, namespace, set, n, asInfoPolicy)
 						if err != nil {
 							continue
 						}
 					}
 
 					if a.EnableObjectSizeLinearHistogram {
-						err = a.getObjectSizeLinearHistogram(hostPort, namespace, set, n, acc)
+						err = a.getObjectSizeLinearHistogram(acc, nodeHost, namespace, set, n, asInfoPolicy)
 						if err != nil {
 							continue
 						}
@@ -229,8 +230,8 @@ func (a *Aerospike) gatherServer(hostPort string, acc telegraf.Accumulator) erro
 	return nil
 }
 
-func (a *Aerospike) getNodeInfo(n *as.Node) (map[string]string, error) {
-	stats, err := as.RequestNodeStats(n)
+func (a *Aerospike) getNodeInfo(n *as.Node, infoPolicy *as.InfoPolicy) (map[string]string, error) {
+	stats, err := n.RequestInfo(infoPolicy)
 	if err != nil {
 		return nil, err
 	}
@@ -238,7 +239,7 @@ func (a *Aerospike) getNodeInfo(n *as.Node) (map[string]string, error) {
 	return stats, nil
 }
 
-func (a *Aerospike) parseNodeInfo(stats map[string]string, hostPort string, nodeName string, acc telegraf.Accumulator) {
+func (a *Aerospike) parseNodeInfo(acc telegraf.Accumulator, stats map[string]string, hostPort string, nodeName string) {
 	tags := map[string]string{
 		"aerospike_host": hostPort,
 		"node_name":      nodeName,
@@ -248,17 +249,14 @@ func (a *Aerospike) parseNodeInfo(stats map[string]string, hostPort string, node
 	for k, v := range stats {
 		key := strings.Replace(k, "-", "_", -1)
 		fields[key] = parseAerospikeValue(key, v)
-
 	}
 	acc.AddFields("aerospike_node", fields, tags, time.Now())
-
-	return
 }
 
-func (a *Aerospike) getNamespaces(n *as.Node) ([]string, error) {
+func (a *Aerospike) getNamespaces(n *as.Node, infoPolicy *as.InfoPolicy) ([]string, error) {
 	var namespaces []string
 	if len(a.Namespaces) <= 0 {
-		info, err := as.RequestNodeInfo(n, "namespaces")
+		info, err := n.RequestInfo(infoPolicy, "namespaces")
 		if err != nil {
 			return namespaces, err
 		}
@@ -270,16 +268,15 @@ func (a *Aerospike) getNamespaces(n *as.Node) ([]string, error) {
 	return namespaces, nil
 }
 
-func (a *Aerospike) getNamespaceInfo(namespace string, n *as.Node) (map[string]string, error) {
-	stats, err := as.RequestNodeInfo(n, "namespace/"+namespace)
+func (a *Aerospike) getNamespaceInfo(namespace string, n *as.Node, infoPolicy *as.InfoPolicy) (map[string]string, error) {
+	stats, err := n.RequestInfo(infoPolicy, "namespace/"+namespace)
 	if err != nil {
 		return nil, err
 	}
 
 	return stats, err
 }
-func (a *Aerospike) parseNamespaceInfo(stats map[string]string, hostPort string, namespace string, nodeName string, acc telegraf.Accumulator) {
-
+func (a *Aerospike) parseNamespaceInfo(acc telegraf.Accumulator, stats map[string]string, hostPort string, namespace string, nodeName string) {
 	nTags := map[string]string{
 		"aerospike_host": hostPort,
 		"node_name":      nodeName,
@@ -297,19 +294,16 @@ func (a *Aerospike) parseNamespaceInfo(stats map[string]string, hostPort string,
 		nFields[key] = parseAerospikeValue(key, parts[1])
 	}
 	acc.AddFields("aerospike_namespace", nFields, nTags, time.Now())
-
-	return
 }
 
-func (a *Aerospike) getSets(n *as.Node) ([]string, error) {
+func (a *Aerospike) getSets(n *as.Node, infoPolicy *as.InfoPolicy) ([]string, error) {
 	var namespaceSets []string
 	// Gather all sets
 	if len(a.Sets) <= 0 {
-		stats, err := as.RequestNodeInfo(n, "sets")
+		stats, err := n.RequestInfo(infoPolicy, "sets")
 		if err != nil {
 			return namespaceSets, err
 		}
-
 		stat := strings.Split(stats["sets"], ";")
 		for _, setStats := range stat {
 			// setInfo is "ns=test:set=foo:objects=1:tombstones=0"
@@ -339,16 +333,15 @@ func (a *Aerospike) getSets(n *as.Node) ([]string, error) {
 	return namespaceSets, nil
 }
 
-func (a *Aerospike) getSetInfo(namespaceSet string, n *as.Node) (map[string]string, error) {
-	stats, err := as.RequestNodeInfo(n, "sets/"+namespaceSet)
+func (a *Aerospike) getSetInfo(namespaceSet string, n *as.Node, infoPolicy *as.InfoPolicy) (map[string]string, error) {
+	stats, err := n.RequestInfo(infoPolicy, "sets/"+namespaceSet)
 	if err != nil {
 		return nil, err
 	}
 	return stats, nil
 }
 
-func (a *Aerospike) parseSetInfo(stats map[string]string, hostPort string, namespaceSet string, nodeName string, acc telegraf.Accumulator) {
-
+func (a *Aerospike) parseSetInfo(acc telegraf.Accumulator, stats map[string]string, hostPort string, namespaceSet string, nodeName string) {
 	stat := strings.Split(
 		strings.TrimSuffix(
 			stats[fmt.Sprintf("sets/%s", namespaceSet)], ";"), ":")
@@ -368,32 +361,33 @@ func (a *Aerospike) parseSetInfo(stats map[string]string, hostPort string, names
 		nFields[key] = parseAerospikeValue(key, pieces[1])
 	}
 	acc.AddFields("aerospike_set", nFields, nTags, time.Now())
-
-	return
 }
 
-func (a *Aerospike) getTTLHistogram(hostPort string, namespace string, set string, n *as.Node, acc telegraf.Accumulator) error {
-	stats, err := a.getHistogram(namespace, set, "ttl", n)
+func (a *Aerospike) getTTLHistogram(acc telegraf.Accumulator, hostPort string, namespace string, set string, n *as.Node, infoPolicy *as.InfoPolicy) error {
+	stats, err := a.getHistogram(namespace, set, "ttl", n, infoPolicy)
 	if err != nil {
 		return err
 	}
-	a.parseHistogram(stats, hostPort, namespace, set, "ttl", n.GetName(), acc)
+
+	nTags := createTags(hostPort, n.GetName(), namespace, set)
+	a.parseHistogram(acc, stats, nTags, "ttl")
 
 	return nil
 }
 
-func (a *Aerospike) getObjectSizeLinearHistogram(hostPort string, namespace string, set string, n *as.Node, acc telegraf.Accumulator) error {
-
-	stats, err := a.getHistogram(namespace, set, "object-size-linear", n)
+func (a *Aerospike) getObjectSizeLinearHistogram(acc telegraf.Accumulator, hostPort string, namespace string, set string, n *as.Node, infoPolicy *as.InfoPolicy) error {
+	stats, err := a.getHistogram(namespace, set, "object-size-linear", n, infoPolicy)
 	if err != nil {
 		return err
 	}
-	a.parseHistogram(stats, hostPort, namespace, set, "object-size-linear", n.GetName(), acc)
+
+	nTags := createTags(hostPort, n.GetName(), namespace, set)
+	a.parseHistogram(acc, stats, nTags, "object-size-linear")
 
 	return nil
 }
 
-func (a *Aerospike) getHistogram(namespace string, set string, histogramType string, n *as.Node) (map[string]string, error) {
+func (a *Aerospike) getHistogram(namespace string, set string, histogramType string, n *as.Node, infoPolicy *as.InfoPolicy) (map[string]string, error) {
 	var queryArg string
 	if len(set) > 0 {
 		queryArg = fmt.Sprintf("histogram:type=%s;namespace=%v;set=%v", histogramType, namespace, set)
@@ -401,26 +395,14 @@ func (a *Aerospike) getHistogram(namespace string, set string, histogramType str
 		queryArg = fmt.Sprintf("histogram:type=%s;namespace=%v", histogramType, namespace)
 	}
 
-	stats, err := as.RequestNodeInfo(n, queryArg)
+	stats, err := n.RequestInfo(infoPolicy, queryArg)
 	if err != nil {
 		return nil, err
 	}
 	return stats, nil
-
 }
 
-func (a *Aerospike) parseHistogram(stats map[string]string, hostPort string, namespace string, set string, histogramType string, nodeName string, acc telegraf.Accumulator) {
-
-	nTags := map[string]string{
-		"aerospike_host": hostPort,
-		"node_name":      nodeName,
-		"namespace":      namespace,
-	}
-
-	if len(set) > 0 {
-		nTags["set"] = set
-	}
-
+func (a *Aerospike) parseHistogram(acc telegraf.Accumulator, stats map[string]string, nTags map[string]string, histogramType string) {
 	nFields := make(map[string]interface{})
 
 	for _, stat := range stats {
@@ -433,10 +415,10 @@ func (a *Aerospike) parseHistogram(stats map[string]string, hostPort string, nam
 			if pieces[0] == "buckets" {
 				buckets := strings.Split(pieces[1], ",")
 
-				// Normalize incase of less buckets than expected
+				// Normalize in case of less buckets than expected
 				numRecordsPerBucket := 1
 				if len(buckets) > a.NumberHistogramBuckets {
-					numRecordsPerBucket = int(math.Ceil((float64(len(buckets)) / float64(a.NumberHistogramBuckets))))
+					numRecordsPerBucket = int(math.Ceil(float64(len(buckets)) / float64(a.NumberHistogramBuckets)))
 				}
 
 				bucketCount := 0
@@ -463,17 +445,14 @@ func (a *Aerospike) parseHistogram(stats map[string]string, hostPort string, nam
 						nFields[strconv.Itoa(bucketName)] = bucketSum
 					}
 				}
-
 			}
 		}
 	}
 
 	acc.AddFields(fmt.Sprintf("aerospike_histogram_%v", strings.Replace(histogramType, "-", "_", -1)), nFields, nTags, time.Now())
-
-	return
 }
 
-func splitNamespaceSet(namespaceSet string) (string, string) {
+func splitNamespaceSet(namespaceSet string) (namespace string, set string) {
 	split := strings.Split(namespaceSet, "/")
 	return split[0], split[1]
 }
@@ -487,18 +466,25 @@ func parseAerospikeValue(key string, v string) interface{} {
 		return parsed
 	} else if parsed, err := strconv.ParseBool(v); err == nil {
 		return parsed
+	} else if parsed, err := strconv.ParseFloat(v, 32); err == nil {
+		return parsed
 	} else {
 		// leave as string
 		return v
 	}
 }
 
-func copyTags(m map[string]string) map[string]string {
-	out := make(map[string]string)
-	for k, v := range m {
-		out[k] = v
+func createTags(hostPort string, nodeName string, namespace string, set string) map[string]string {
+	nTags := map[string]string{
+		"aerospike_host": hostPort,
+		"node_name":      nodeName,
+		"namespace":      namespace,
 	}
-	return out
+
+	if len(set) > 0 {
+		nTags["set"] = set
+	}
+	return nTags
 }
 
 func init() {
