@@ -15,12 +15,15 @@ import (
 	"github.com/gosnmp/gosnmp"
 )
 
-var defaultTimeout = config.Duration(time.Second * 5)
+type translator interface {
+	lookup(oid string) (snmp.MibEntry, error)
+}
 
 type SnmpTrap struct {
 	ServiceAddress string          `toml:"service_address"`
-	Timeout        config.Duration `toml:"timeout"`
+	Timeout        config.Duration `toml:"timeout" deprecated:"1.20.0;unused option"`
 	Version        string          `toml:"version"`
+	Translator     string          `toml:"-"`
 	Path           []string        `toml:"path"`
 
 	// Settings for version 3
@@ -34,15 +37,16 @@ type SnmpTrap struct {
 	PrivProtocol string `toml:"priv_protocol"`
 	PrivPassword string `toml:"priv_password"`
 
-	acc        telegraf.Accumulator
-	listener   *gosnmp.TrapListener
-	timeFunc   func() time.Time
-	lookupFunc func(string) (snmp.MibEntry, error)
-	errCh      chan error
+	acc      telegraf.Accumulator
+	listener *gosnmp.TrapListener
+	timeFunc func() time.Time
+	errCh    chan error
 
 	makeHandlerWrapper func(gosnmp.TrapHandlerFunc) gosnmp.TrapHandlerFunc
 
 	Log telegraf.Logger `toml:"-"`
+
+	translator translator //nolint:revive
 }
 
 var sampleConfig = `
@@ -58,9 +62,6 @@ var sampleConfig = `
   ## Path to mib files
   # path = ["/usr/share/snmp/mibs"]
   ##
-  ## Deprecated in 1.20.0; no longer running snmptranslate
-  ## Timeout running snmptranslate command
-  # timeout = "5s"
   ## Snmp version, defaults to 2c
   # version = "2c"
   ## SNMPv3 authentication and encryption options.
@@ -95,17 +96,31 @@ func init() {
 	inputs.Add("snmp_trap", func() telegraf.Input {
 		return &SnmpTrap{
 			timeFunc:       time.Now,
-			lookupFunc:     snmp.TrapLookup,
 			ServiceAddress: "udp://:162",
-			Timeout:        defaultTimeout,
 			Path:           []string{"/usr/share/snmp/mibs"},
 			Version:        "2c",
 		}
 	})
 }
 
+func (s *SnmpTrap) SetTranslator(name string) {
+	s.Translator = name
+}
+
 func (s *SnmpTrap) Init() error {
-	err := snmp.LoadMibsFromPath(s.Path, s.Log)
+	var err error
+	switch s.Translator {
+	case "gosmi":
+		s.translator, err = newGosmiTranslator(s.Path, s.Log)
+		if err != nil {
+			return err
+		}
+	case "netsnmp":
+		s.translator = newNetsnmpTranslator()
+	default:
+		return fmt.Errorf("invalid translator value")
+	}
+
 	if err != nil {
 		s.Log.Errorf("Could not get path %v", err)
 	}
@@ -265,7 +280,7 @@ func makeTrapHandler(s *SnmpTrap) gosnmp.TrapHandlerFunc {
 			}
 
 			if trapOid != "" {
-				e, err := s.lookupFunc(trapOid)
+				e, err := s.translator.lookup(trapOid)
 				if err != nil {
 					s.Log.Errorf("Error resolving V1 OID, oid=%s, source=%s: %v", trapOid, tags["source"], err)
 					return
@@ -303,7 +318,7 @@ func makeTrapHandler(s *SnmpTrap) gosnmp.TrapHandlerFunc {
 
 				var e snmp.MibEntry
 				var err error
-				e, err = s.lookupFunc(val)
+				e, err = s.translator.lookup(val)
 				if nil != err {
 					s.Log.Errorf("Error resolving value OID, oid=%s, source=%s: %v", val, tags["source"], err)
 					return
@@ -321,7 +336,7 @@ func makeTrapHandler(s *SnmpTrap) gosnmp.TrapHandlerFunc {
 				value = v.Value
 			}
 
-			e, err := s.lookupFunc(v.Name)
+			e, err := s.translator.lookup(v.Name)
 			if nil != err {
 				s.Log.Errorf("Error resolving OID oid=%s, source=%s: %v", v.Name, tags["source"], err)
 				return
